@@ -1,4 +1,5 @@
 from django.core.paginator import EmptyPage, PageNotAnInteger, Paginator
+from rescape_python_helpers import ramda as R
 from graphene import Int, Boolean, ObjectType, List
 
 from rescape_graphene import DENY
@@ -7,16 +8,15 @@ from rescape_graphene import DENY
 def get_paginator(qs, page_size, page, paginated_type, **kwargs):
     """
     Adapted from https://gist.github.com/mbrochh/f92594ab8188393bd83c892ef2af25e6
-    First we create a little helper function, becase we will potentially have many PaginatedTypes
-    and we will potentially want to turn many querysets into paginated results:
+    Creates a pagination_type based on the paginated_type function
     :param qs:
     :param page_size:
     :param page:
     :param paginated_type:
-    :param kwargs:
+    :param kwargs: Additional kwargs to pass paginated_type function, usually unneeded
     :return:
     """
-    p = Paginator(qs, page_size)
+    p = Paginator(qs.order_by('id'), page_size)
     try:
         page_obj = p.page(page)
     except PageNotAnInteger:
@@ -74,3 +74,36 @@ def create_paginated_type_mixin(model_object_type, model_object_type_fields):
     )
 
     return dict(type=paginated_type_mixin, fields=paginated_fields)
+
+
+def resolve_paginated_for_type(paginated_type, type_resolver, **kwargs):
+    """
+        Resolver for paginated types
+    :param paginated_type: The paginated Type, e.g. LocationPaginationType
+    :param type_resolver: The resolver for the non-paginated type, e.g. location_resolver
+    :param kwargs: The kwargs Array of prop sets for the non-paginated objects in 'objects'.
+    Normally it's just a 1-item array.
+    Other required kwargs are for pagination are page_size and page
+    :return: The paginated query
+    """
+
+    def reduce_or(q_expressions):
+        return R.reduce(
+            lambda qs, q: qs | q if qs else q,
+            None,
+            q_expressions
+        )
+
+    objects = R.prop_or({}, 'objects', kwargs)
+
+    instances = reduce_or(R.map(
+        lambda obj: type_resolver('filter', **obj),
+        objects
+    ))
+
+    return get_paginator(
+        instances,
+        R.prop('page_size', kwargs),
+        R.prop('page', kwargs),
+        paginated_type
+    )
