@@ -1,11 +1,12 @@
 import inspect
+import uuid
 
 from django.db.models import Q
 from rescape_python_helpers import ramda as R
 
 
 def default_strategy(matches, prop_value, i):
-    return '%s%s' % (prop_value, i + 1)
+    return '%s%s' % (prop_value, str(uuid.uuid1())[0:10])
 
 
 @R.curry
@@ -44,7 +45,7 @@ def increment_prop_until_unique(django_class, strategy, prop, additional_filter_
                 lambda f: f(django_instance_data)
             )(additional_filter_props or {})
         )
-    ).values_list(prop, flat=True)
+    ).values_list(prop, flat=True).order_by(prop)
 
     success = prop_value
     for i, matching_key in enumerate(matching_values):
